summaryrefslogtreecommitdiffstats
path: root/style
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-03 22:54:09 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-03 22:54:09 -0600
commitb063e7d3b4a86f46759db906ff2d907f33c96696 (patch)
tree2a9c1c3237cc2b7d2467c019048b118f66339266 /style
parentf7ed00bca5c1789e9dfc80baa46ea6b3eb99f377 (diff)
downloadtde-style-qtcurve-b063e7d3b4a86f46759db906ff2d907f33c96696.tar.gz
tde-style-qtcurve-b063e7d3b4a86f46759db906ff2d907f33c96696.zip
Rename KStyle to TDEStyle to avoid conflicts with KDE4
Diffstat (limited to 'style')
-rw-r--r--style/qtc_kstyle.cpp88
-rw-r--r--style/qtc_kstyle.h90
-rw-r--r--style/qtcurve.cpp10
-rw-r--r--style/qtcurve.h8
4 files changed, 98 insertions, 98 deletions
diff --git a/style/qtcurve.h b/style/qtcurve.h
index f9a5b95..63e3382 100644
--- a/style/qtcurve.h
+++ b/style/qtcurve.h
@@ -69,9 +69,9 @@ class TQTimer;
class TQSlider;
#ifdef TQTC_TQT_ONLY
-#define BASE_STYLE TQtCKStyle
+#define BASE_STYLE TQtCTDEStyle
#else
-#define BASE_STYLE KStyle
+#define BASE_STYLE TDEStyle
#endif
class QtCurveStyle : public BASE_STYLE
@@ -160,7 +160,7 @@ class QtCurveStyle : public BASE_STYLE
TQ_PrimitiveElement pe, bool small=false, bool checkActive=false) const;
void drawPrimitive(TQ_PrimitiveElement, TQPainter *, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQRect &, const TQColorGroup &,
SFlags = Style_Default, const TQStyleOption & = TQStyleOption::Default) const;
- void drawKStylePrimitive(KStylePrimitive kpe, TQPainter* p, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQRect &r,
+ void drawTDEStylePrimitive(TDEStylePrimitive kpe, TQPainter* p, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQRect &r,
const TQColorGroup &cg, SFlags flags, const TQStyleOption &opt, const TQWidget* widget = 0 ) const;
void drawControl(ControlElement, TQPainter *, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQRect &, const TQColorGroup &,
SFlags = Style_Default, const TQStyleOption & = TQStyleOption::Default, const TQWidget * = 0) const;
@@ -175,7 +175,7 @@ class QtCurveStyle : public BASE_STYLE
TQRect querySubControlMetrics(TQ_ComplexControl, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, SubControl,
const TQStyleOption & = TQStyleOption::Default, const TQWidget * = 0) const;
int pixelMetric(PixelMetric, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQWidget *widget= 0) const;
- int kPixelMetric(KStylePixelMetric kpm, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQWidget *widget) const;
+ int kPixelMetric(TDEStylePixelMetric kpm, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQWidget *widget) const;
TQSize sizeFromContents(ContentsType, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQSize &,
const TQStyleOption & = TQStyleOption::Default, const TQWidget * = 0) const;
int styleHint(StyleHint, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQStyleOption & = TQStyleOption::Default,
diff --git a/style/qtc_kstyle.cpp b/style/qtc_kstyle.cpp
index d29451b..35ef5b3 100644
--- a/style/qtc_kstyle.cpp
+++ b/style/qtc_kstyle.cpp
@@ -1,6 +1,6 @@
/*
*
- * TQtCKStyle
+ * TQtCTDEStyle
* Copyright (C) 2001-2002 Karol Szwed <gallium@kde.org>
*
* TQWindowsStyle CC_ListView and style images were kindly donated by TrollTech,
@@ -56,7 +56,7 @@
#include <limits.h>
-struct TQtCKStylePrivate
+struct TQtCTDEStylePrivate
{
bool highcolor : 1;
bool useFilledFrameWorkaround : 1;
@@ -68,8 +68,8 @@ struct TQtCKStylePrivate
int popupMenuDelay;
float menuOpacity;
- TQtCKStyle::KStyleScrollBarType scrollbarType;
- TQtCKStyle::KStyleFlags flags;
+ TQtCTDEStyle::TDEStyleScrollBarType scrollbarType;
+ TQtCTDEStyle::TDEStyleFlags flags;
//For KPE_ListViewBranch
TQBitmap *verticalLine;
@@ -79,8 +79,8 @@ struct TQtCKStylePrivate
// -----------------------------------------------------------------------------
-TQtCKStyle::TQtCKStyle( KStyleFlags flags, KStyleScrollBarType sbtype )
- : TQCommonStyle(), d(new TQtCKStylePrivate)
+TQtCTDEStyle::TQtCTDEStyle( TDEStyleFlags flags, TDEStyleScrollBarType sbtype )
+ : TQCommonStyle(), d(new TQtCTDEStylePrivate)
{
d->flags = flags;
d->useFilledFrameWorkaround = (flags & FilledFrameWorkaround);
@@ -89,19 +89,19 @@ TQtCKStyle::TQtCKStyle( KStyleFlags flags, KStyleScrollBarType sbtype )
// Read style settings
TQSettings settings;
- d->popupMenuDelay = settings.readNumEntry ("/TQtCKStyle/Settings/PopupMenuDelay", 256);
- d->sloppySubMenus = settings.readBoolEntry("/TQtCKStyle/Settings/SloppySubMenus", false);
- d->etchDisabledText = settings.readBoolEntry("/TQtCKStyle/Settings/EtchDisabledText", true);
- d->menuAltKeyNavigation = settings.readBoolEntry("/TQtCKStyle/Settings/MenuAltKeyNavigation", true);
- d->scrollablePopupmenus = settings.readBoolEntry("/TQtCKStyle/Settings/ScrollablePopupMenus", false);
- d->menuDropShadow = settings.readBoolEntry("/TQtCKStyle/Settings/MenuDropShadow", false);
+ d->popupMenuDelay = settings.readNumEntry ("/TQtCTDEStyle/Settings/PopupMenuDelay", 256);
+ d->sloppySubMenus = settings.readBoolEntry("/TQtCTDEStyle/Settings/SloppySubMenus", false);
+ d->etchDisabledText = settings.readBoolEntry("/TQtCTDEStyle/Settings/EtchDisabledText", true);
+ d->menuAltKeyNavigation = settings.readBoolEntry("/TQtCTDEStyle/Settings/MenuAltKeyNavigation", true);
+ d->scrollablePopupmenus = settings.readBoolEntry("/TQtCTDEStyle/Settings/ScrollablePopupMenus", false);
+ d->menuDropShadow = settings.readBoolEntry("/TQtCTDEStyle/Settings/MenuDropShadow", false);
d->verticalLine = 0;
d->horizontalLine = 0;
}
-TQtCKStyle::~TQtCKStyle()
+TQtCTDEStyle::~TQtCTDEStyle()
{
delete d->verticalLine;
delete d->horizontalLine;
@@ -110,7 +110,7 @@ TQtCKStyle::~TQtCKStyle()
}
-TQString TQtCKStyle::defaultStyle()
+TQString TQtCTDEStyle::defaultStyle()
{
if (TQPixmap::defaultDepth() > 8)
return TQString("plastik");
@@ -119,7 +119,7 @@ TQString TQtCKStyle::defaultStyle()
}
-void TQtCKStyle::polish( TQStyleControlElementData ceData, ControlElementFlags elementFlags, void *ptr )
+void TQtCTDEStyle::polish( TQStyleControlElementData ceData, ControlElementFlags elementFlags, void *ptr )
{
if (ceData.widgetObjectTypes.contains(TQWIDGET_OBJECT_NAME_STRING)) {
TQWidget *widget = reinterpret_cast<TQWidget*>(ptr);
@@ -136,7 +136,7 @@ void TQtCKStyle::polish( TQStyleControlElementData ceData, ControlElementFlags e
}
-void TQtCKStyle::unPolish( TQStyleControlElementData ceData, ControlElementFlags elementFlags, void *ptr )
+void TQtCTDEStyle::unPolish( TQStyleControlElementData ceData, ControlElementFlags elementFlags, void *ptr )
{
if (ceData.widgetObjectTypes.contains(TQWIDGET_OBJECT_NAME_STRING)) {
TQWidget *widget = reinterpret_cast<TQWidget*>(ptr);
@@ -154,7 +154,7 @@ void TQtCKStyle::unPolish( TQStyleControlElementData ceData, ControlElementFlags
// Style changes (should) always re-polish popups.
-void TQtCKStyle::polishPopupMenu( TQStyleControlElementData ceData, ControlElementFlags elementFlags, void *ptr )
+void TQtCTDEStyle::polishPopupMenu( TQStyleControlElementData ceData, ControlElementFlags elementFlags, void *ptr )
{
if ( !(ceData.windowState & WState_Polished ) ) {
widgetActionRequest(ceData, elementFlags, ptr, WAR_SetCheckable);
@@ -163,20 +163,20 @@ void TQtCKStyle::polishPopupMenu( TQStyleControlElementData ceData, ControlEleme
// -----------------------------------------------------------------------------
-// TQtCKStyle extensions
+// TQtCTDEStyle extensions
// -----------------------------------------------------------------------------
-void TQtCKStyle::setScrollBarType(KStyleScrollBarType sbtype)
+void TQtCTDEStyle::setScrollBarType(TDEStyleScrollBarType sbtype)
{
d->scrollbarType = sbtype;
}
-TQtCKStyle::KStyleFlags TQtCKStyle::styleFlags() const
+TQtCTDEStyle::TDEStyleFlags TQtCTDEStyle::styleFlags() const
{
return d->flags;
}
-void TQtCKStyle::drawKStylePrimitive( KStylePrimitive kpe,
+void TQtCTDEStyle::drawTDEStylePrimitive( TDEStylePrimitive kpe,
TQPainter* p,
TQStyleControlElementData ceData,
ControlElementFlags elementFlags,
@@ -364,7 +364,7 @@ void TQtCKStyle::drawKStylePrimitive( KStylePrimitive kpe,
}
-int TQtCKStyle::kPixelMetric( KStylePixelMetric kpm, TQStyleControlElementData ceData, ControlElementFlags elementFlags, const TQWidget* /* widget */) const
+int TQtCTDEStyle::kPixelMetric( TDEStylePixelMetric kpm, TQStyleControlElementData ceData, ControlElementFlags elementFlags, const TQWidget* /* widget */) const
{
int value;
switch(kpm)
@@ -391,7 +391,7 @@ int TQtCKStyle::kPixelMetric( KStylePixelMetric kpm, TQStyleControlElementData c
// -----------------------------------------------------------------------------
-void TQtCKStyle::drawPrimitive( PrimitiveElement pe,
+void TQtCTDEStyle::drawPrimitive( PrimitiveElement pe,
TQPainter* p,
TQStyleControlElementData ceData,
ControlElementFlags elementFlags,
@@ -419,16 +419,16 @@ void TQtCKStyle::drawPrimitive( PrimitiveElement pe,
(parent->inherits(TQMAINWINDOW_OBJECT_NAME_STRING)) )) // Collapsed dock
// Draw a toolbar handle
- drawKStylePrimitive( KPE_ToolBarHandle, p, ceData, elementFlags, r, cg, flags, opt, widget );
+ drawTDEStylePrimitive( KPE_ToolBarHandle, p, ceData, elementFlags, r, cg, flags, opt, widget );
else if ( widget->inherits(TQDOCKWINDOWHANDLE_OBJECT_NAME_STRING) )
// Draw a dock window handle
- drawKStylePrimitive( KPE_DockWindowHandle, p, ceData, elementFlags, r, cg, flags, opt, widget );
+ drawTDEStylePrimitive( KPE_DockWindowHandle, p, ceData, elementFlags, r, cg, flags, opt, widget );
else
// General handle, probably a kicker applet handle.
- drawKStylePrimitive( KPE_GeneralHandle, p, ceData, elementFlags, r, cg, flags, opt, widget );
+ drawTDEStylePrimitive( KPE_GeneralHandle, p, ceData, elementFlags, r, cg, flags, opt, widget );
} else
TQCommonStyle::drawPrimitive( pe, p, ceData, elementFlags, r, cg, flags, opt );
@@ -436,7 +436,7 @@ void TQtCKStyle::drawPrimitive( PrimitiveElement pe,
-void TQtCKStyle::drawControl( ControlElement element,
+void TQtCTDEStyle::drawControl( ControlElement element,
TQPainter* p,
TQStyleControlElementData ceData,
ControlElementFlags elementFlags,
@@ -741,7 +741,7 @@ void TQtCKStyle::drawControl( ControlElement element,
}
-TQRect TQtCKStyle::subRect(SubRect r, const TQStyleControlElementData ceData, const ControlElementFlags elementFlags, const TQWidget* widget) const
+TQRect TQtCTDEStyle::subRect(SubRect r, const TQStyleControlElementData ceData, const ControlElementFlags elementFlags, const TQWidget* widget) const
{
switch(r)
{
@@ -763,7 +763,7 @@ TQRect TQtCKStyle::subRect(SubRect r, const TQStyleControlElementData ceData, co
}
-int TQtCKStyle::pixelMetric(PixelMetric m, TQStyleControlElementData ceData, ControlElementFlags elementFlags, const TQWidget* widget) const
+int TQtCTDEStyle::pixelMetric(PixelMetric m, TQStyleControlElementData ceData, ControlElementFlags elementFlags, const TQWidget* widget) const
{
switch(m)
{
@@ -888,7 +888,7 @@ static TQListViewItem* nextVisibleSibling(TQListViewItem* item)
return sibling;
}
-void TQtCKStyle::drawComplexControl( ComplexControl control,
+void TQtCTDEStyle::drawComplexControl( ComplexControl control,
TQPainter* p,
TQStyleControlElementData ceData,
ControlElementFlags elementFlags,
@@ -1004,7 +1004,7 @@ void TQtCKStyle::drawComplexControl( ComplexControl control,
// Draw slider groove
if ((controls & SC_SliderGroove) && groove.isValid()) {
- drawKStylePrimitive( KPE_SliderGroove, &p2, ceData, elementFlags, groove, cg, flags, opt, widget );
+ drawTDEStylePrimitive( KPE_SliderGroove, &p2, ceData, elementFlags, groove, cg, flags, opt, widget );
// Draw the focus rect around the groove
if (slider->hasFocus())
@@ -1020,7 +1020,7 @@ void TQtCKStyle::drawComplexControl( ComplexControl control,
if ((controls & SC_SliderHandle) && handle.isValid()) {
if (active == SC_SliderHandle)
flags |= Style_Active;
- drawKStylePrimitive( KPE_SliderHandle, &p2, ceData, elementFlags, handle, cg, flags, opt, widget );
+ drawTDEStylePrimitive( KPE_SliderHandle, &p2, ceData, elementFlags, handle, cg, flags, opt, widget );
}
p2.end();
@@ -1100,8 +1100,8 @@ void TQtCKStyle::drawComplexControl( ComplexControl control,
boxrect = TQRect( bx-4, linebot-4, 9, 9 );
boxflags = child->isOpen() ? TQStyle::Style_Off : TQStyle::Style_On;
- // TQtCKStyle extension: Draw the box and expand/collapse indicator
- drawKStylePrimitive( KPE_ListViewExpander, p, ceData, elementFlags, boxrect, cg, boxflags, opt, NULL );
+ // TQtCTDEStyle extension: Draw the box and expand/collapse indicator
+ drawTDEStylePrimitive( KPE_ListViewExpander, p, ceData, elementFlags, boxrect, cg, boxflags, opt, NULL );
// dotlinery
p->setPen( cg.mid() );
@@ -1154,8 +1154,8 @@ void TQtCKStyle::drawComplexControl( ComplexControl control,
branchrect = TQRect( point, other-(thickness/2), end-point, thickness );
branchflags = TQStyle::Style_Horizontal;
- // TQtCKStyle extension: Draw the horizontal branch
- drawKStylePrimitive( KPE_ListViewBranch, p, ceData, elementFlags, branchrect, cg, branchflags, opt, NULL );
+ // TQtCTDEStyle extension: Draw the horizontal branch
+ drawTDEStylePrimitive( KPE_ListViewBranch, p, ceData, elementFlags, branchrect, cg, branchflags, opt, NULL );
} else {
// Vertical branch
@@ -1170,8 +1170,8 @@ void TQtCKStyle::drawComplexControl( ComplexControl control,
else
branchflags = TQStyle::Style_Default;
- // TQtCKStyle extension: Draw the vertical branch
- drawKStylePrimitive( KPE_ListViewBranch, p, ceData, elementFlags, branchrect, cg, branchflags, opt, NULL );
+ // TQtCTDEStyle extension: Draw the vertical branch
+ drawTDEStylePrimitive( KPE_ListViewBranch, p, ceData, elementFlags, branchrect, cg, branchflags, opt, NULL );
}
}
}
@@ -1186,7 +1186,7 @@ void TQtCKStyle::drawComplexControl( ComplexControl control,
}
-TQStyle::SubControl TQtCKStyle::querySubControl( ComplexControl control,
+TQStyle::SubControl TQtCTDEStyle::querySubControl( ComplexControl control,
TQStyleControlElementData ceData,
ControlElementFlags elementFlags,
const TQPoint &pos,
@@ -1204,7 +1204,7 @@ TQStyle::SubControl TQtCKStyle::querySubControl( ComplexControl control,
}
-TQRect TQtCKStyle::querySubControlMetrics( ComplexControl control,
+TQRect TQtCTDEStyle::querySubControlMetrics( ComplexControl control,
TQStyleControlElementData ceData,
ControlElementFlags elementFlags,
SubControl sc,
@@ -1591,7 +1591,7 @@ static const char* const critical_xpm[]={
"...........aaaaaaaaaaa..........",
".............aaaaaaa............"};
-TQPixmap TQtCKStyle::stylePixmap( StylePixmap stylepixmap,
+TQPixmap TQtCTDEStyle::stylePixmap( StylePixmap stylepixmap,
TQStyleControlElementData ceData,
ControlElementFlags elementFlags,
const TQStyleOption& opt,
@@ -1625,7 +1625,7 @@ TQPixmap TQtCKStyle::stylePixmap( StylePixmap stylepixmap,
}
-int TQtCKStyle::styleHint( StyleHint sh, TQStyleControlElementData ceData, ControlElementFlags elementFlags,
+int TQtCTDEStyle::styleHint( StyleHint sh, TQStyleControlElementData ceData, ControlElementFlags elementFlags,
const TQStyleOption &opt, TQStyleHintReturn* shr, const TQWidget* w) const
{
switch (sh)
@@ -1680,7 +1680,7 @@ int TQtCKStyle::styleHint( StyleHint sh, TQStyleControlElementData ceData, Contr
}
}
-bool TQtCKStyle::objectEventHandler( TQStyleControlElementData ceData, ControlElementFlags elementFlags, void* source, TQEvent *event )
+bool TQtCTDEStyle::objectEventHandler( TQStyleControlElementData ceData, ControlElementFlags elementFlags, void* source, TQEvent *event )
{
if (ceData.widgetObjectTypes.contains(TQOBJECT_OBJECT_NAME_STRING)) {
TQObject* object = reinterpret_cast<TQObject*>(source);
@@ -1734,7 +1734,7 @@ bool TQtCKStyle::objectEventHandler( TQStyleControlElementData ceData, ControlEl
return false;
}
-void TQtCKStyle::virtual_hook( int, void* )
+void TQtCTDEStyle::virtual_hook( int, void* )
{ /*BASE::virtual_hook( id, data );*/ }
// vim: set noet ts=4 sw=4:
diff --git a/style/qtc_kstyle.h b/style/qtc_kstyle.h
index 63fa4fc..28fa024 100644
--- a/style/qtc_kstyle.h
+++ b/style/qtc_kstyle.h
@@ -1,7 +1,7 @@
/*
* $Id$
*
- * KStyle
+ * TDEStyle
* Copyright (C) 2001-2002 Karol Szwed <gallium@kde.org>
*
* TQWindowsStyle CC_ListView and style images were kindly donated by TrollTech,
@@ -34,11 +34,11 @@
#include <tqcommonstyle.h>
-struct TQtCKStylePrivate;
+struct TQtCTDEStylePrivate;
/**
* Simplifies and extends the TQStyle API to make style coding easier.
*
* The KStyle class provides a simple internal menu transparency engine
* which attempts to use XRender for accelerated blending where requested,
* or falls back to fast internal software tinting/blending routines.
* It also simplifies more complex portions of the TQStyle API, such as
@@ -50,7 +50,7 @@ struct TQtCKStylePrivate;
* @author Karol Szwed (gallium@kde.org)
* @version $Id$
*/
-class TQtCKStyle: public TQCommonStyle
+class TQtCTDEStyle: public TQCommonStyle
{
Q_OBJECT
@@ -58,12 +58,12 @@ class TQtCKStyle: public TQCommonStyle
public:
/**
- * TQtCKStyle Flags:
+ * TQtCTDEStyle Flags:
*
* @li Default - Default style setting, where menu transparency
* and the FilledFrameWorkaround are disabled.
*
* @li AllowMenuTransparency - Enable this flag to use TQtCKStyle's
* internal menu transparency engine.
*
* @li FilledFrameWorkaround - Enable this flag to facilitate
@@ -73,15 +73,15 @@ class TQtCKStyle: public TQCommonStyle
* this workaround to enable painting of gradients in menubars and
* toolbars.
*/
- typedef uint KStyleFlags;
- enum KStyleOption {
+ typedef uint TDEStyleFlags;
+ enum TDEStyleOption {
Default = 0x00000000, //!< All options disabled
AllowMenuTransparency = 0x00000001, //!< Internal transparency enabled
FilledFrameWorkaround = 0x00000002 //!< Filled frames enabled
};
/**
- * KStyle ScrollBarType:
+ * TDEStyle ScrollBarType:
*
* Allows the style writer to easily select what type of scrollbar
* should be used without having to duplicate large amounts of source
@@ -101,9 +101,9 @@ class TQtCKStyle: public TQCommonStyle
* @li NextStyleScrollBar - Similar to the PlatinumStyle scroll bar, but
* with the buttons grouped on the opposite end of the scrollbar.
*
- * @see KStyle::KStyle()
+ * @see TDEStyle::TDEStyle()
*/
- enum KStyleScrollBarType {
+ enum TDEStyleScrollBarType {
WindowsStyleScrollBar = 0x00000000, //!< two button, windows style
PlatinumStyleScrollBar = 0x00000001, //!< two button, platinum style
ThreeButtonScrollBar = 0x00000002, //!< three buttons, %KDE style
@@ -111,31 +111,31 @@ class TQtCKStyle: public TQCommonStyle
};
/**
* Constructs a KStyle object.
*
* Select the appropriate KStyle flags and scrollbar type
* for your style. The user's style preferences selected in KControl
* are read by using TQSettings and are automatically applied to the style.
* As a fallback, KStyle paints progressbars and tabbars. It inherits from
* TQCommonStyle for speed, so don't expect much to be implemented.
*
* It is advisable to use a currently implemented style such as the HighColor
* style as a foundation for any new KStyle, so the limited number of
* drawing fallbacks should not prove problematic.
*
* @param flags the style to be applied
* @param sbtype the scroll bar type
- * @see KStyle::KStyleFlags
- * @see KStyle::KStyleScrollBarType
+ * @see TDEStyle::TDEStyleFlags
+ * @see TDEStyle::TDEStyleScrollBarType
* @author Karol Szwed (gallium@kde.org)
*/
- TQtCKStyle( KStyleFlags flags = TQtCKStyle::Default,
- KStyleScrollBarType sbtype = TQtCKStyle::WindowsStyleScrollBar );
+ TQtCTDEStyle( TDEStyleFlags flags = TQtCTDEStyle::Default,
+ TDEStyleScrollBarType sbtype = TQtCTDEStyle::WindowsStyleScrollBar );
/**
* Destructs the TQtCKStyle object.
*/
- ~TQtCKStyle();
+ ~TQtCTDEStyle();
/**
* Returns the default widget style depending on color depth.
@@ -148,35 +148,35 @@ class TQtCKStyle: public TQCommonStyle
* This function is only provided for convenience. It allows
* you to make a late decision about what scrollbar type to use for the
* style after performing some processing in your style's constructor.
* In most situations however, setting the scrollbar type via the TQtCKStyle
* constructor should suffice.
* @param sbtype the scroll bar type
- * @see TQtCKStyle::KStyleScrollBarType
+ * @see TQtCTDEStyle::TDEStyleScrollBarType
*/
- void setScrollBarType(KStyleScrollBarType sbtype);
+ void setScrollBarType(TDEStyleScrollBarType sbtype);
/**
* Returns the KStyle flags used to initialize the style.
*
* This is used solely for the kcmstyle module, and hence is internal.
*/
- KStyleFlags styleFlags() const;
+ TDEStyleFlags styleFlags() const;
/**
* KStyle Primitive Elements:
*
* The KStyle class extends the TQt's Style API by providing certain
* simplifications for parts of TQStyle. To do this, the KStylePrimitive
* elements were defined, which are very similar to TQt's PrimitiveElement.
*
* The first three Handle primitives simplify and extend PE_DockWindowHandle,
* so do not reimplement PE_DockWindowHandle if you want the KStyle handle
* simplifications to be operable. Similarly do not reimplement CC_Slider,
* SC_SliderGroove and SC_SliderHandle when using the KStyle slider
* primitives. KStyle automatically double-buffers slider painting
* when they are drawn via these KStyle primitives to avoid flicker.
*
* @li KPE_DockWindowHandle - This primitive is already implemented in KStyle,
* and paints a bevelled rect with the DockWindow caption text. Re-implement
* this primitive to perform other more fancy effects when drawing the dock window
* handle.
@@ -198,14 +198,14 @@ class TQtCKStyle: public TQCommonStyle
* paint the slider handle. The default implementation paints a filled rect of
* arbitrary color.
*
* @li KPE_ListViewExpander - This primitive is already implemented in KStyle. It
* is used to draw the Expand/Collapse element in TQListViews. To indicate the
* expanded state, the style flags are set to Style_Off, while Style_On implies collapsed.
*
* @li KPE_ListViewBranch - This primitive is already implemented in KStyle. It is
* used to draw the ListView branches where necessary.
*/
- enum KStylePrimitive {
+ enum TDEStylePrimitive {
KPE_DockWindowHandle,
KPE_ToolBarHandle,
KPE_GeneralHandle,
@@ -220,13 +220,13 @@ class TQtCKStyle: public TQCommonStyle
/**
* This function is identical to TQt's TQStyle::drawPrimitive(), except that
* it adds one further parameter, 'widget', that can be used to determine
* the widget state of the KStylePrimitive in question.
*
- * @see KStyle::KStylePrimitive
+ * @see TDEStyle::TDEStylePrimitive
* @see TQStyle::drawPrimitive
* @see TQStyle::drawComplexControl
*/
- virtual void drawKStylePrimitive( KStylePrimitive kpe,
+ virtual void drawTDEStylePrimitive( TDEStylePrimitive kpe,
TQPainter* p,
TQStyleControlElementData ceData,
ControlElementFlags elementFlags,
@@ -237,7 +237,7 @@ class TQtCKStyle: public TQCommonStyle
const TQWidget* widget = 0 ) const;
- enum KStylePixelMetric {
+ enum TDEStylePixelMetric {
KPM_MenuItemSeparatorHeight = 0x00000001,
KPM_MenuItemHMargin = 0x00000002,
KPM_MenuItemVMargin = 0x00000004,
@@ -249,7 +249,7 @@ class TQtCKStyle: public TQCommonStyle
KPM_ListViewBranchThickness = 0x00000100
};
- int kPixelMetric( KStylePixelMetric kpm, TQStyleControlElementData ceData, ControlElementFlags elementFlags, const TQWidget* widget = 0 ) const;
+ int kPixelMetric( TDEStylePixelMetric kpm, TQStyleControlElementData ceData, ControlElementFlags elementFlags, const TQWidget* widget = 0 ) const;
// ---------------------------------------------------------------------------
@@ -324,13 +324,13 @@ class TQtCKStyle: public TQCommonStyle
private:
// Disable copy constructor and = operator
- TQtCKStyle( const TQtCKStyle & );
- TQtCKStyle& operator=( const TQtCKStyle & );
+ TQtCTDEStyle( const TQtCTDEStyle & );
+ TQtCTDEStyle& operator=( const TQtCTDEStyle & );
protected:
virtual void virtual_hook( int id, void* data );
private:
- TQtCKStylePrivate *d;
+ TQtCTDEStylePrivate *d;
};
@@ -34,11 +34,11 @@
* Simplifies and extends the TQStyle API to make style coding easier.
*
- * The KStyle class provides a simple internal menu transparency engine
+ * The TDEStyle class provides a simple internal menu transparency engine
* which attempts to use XRender for accelerated blending where requested,
* or falls back to fast internal software tinting/blending routines.
@@ -58,12 +58,12 @@ class TQtCKStyle: public TQCommonStyle
* and the FilledFrameWorkaround are disabled.
*
- * @li AllowMenuTransparency - Enable this flag to use TQtCKStyle's
+ * @li AllowMenuTransparency - Enable this flag to use TQtCTDEStyle's
* internal menu transparency engine.
*
@@ -111,31 +111,31 @@ class TQtCKStyle: public TQCommonStyle
};
/**
- * Constructs a KStyle object.
+ * Constructs a TDEStyle object.
*
@@ -111,31 +111,31 @@ class TQtCKStyle: public TQCommonStyle
*
- * Select the appropriate KStyle flags and scrollbar type
+ * Select the appropriate TDEStyle flags and scrollbar type
* for your style. The user's style preferences selected in KControl
* are read by using TQSettings and are automatically applied to the style.
@@ -111,31 +111,31 @@ class TQtCKStyle: public TQCommonStyle
* for your style. The user's style preferences selected in KControl
* are read by using TQSettings and are automatically applied to the style.
- * As a fallback, KStyle paints progressbars and tabbars. It inherits from
+ * As a fallback, TDEStyle paints progressbars and tabbars. It inherits from
* TQCommonStyle for speed, so don't expect much to be implemented.
*
@@ -111,31 +111,31 @@ class TQtCKStyle: public TQCommonStyle
*
* It is advisable to use a currently implemented style such as the HighColor
- * style as a foundation for any new KStyle, so the limited number of
+ * style as a foundation for any new TDEStyle, so the limited number of
* drawing fallbacks should not prove problematic.
*
@@ -111,31 +111,31 @@ class TQtCKStyle: public TQCommonStyle
/**
- * Destructs the TQtCKStyle object.
+ * Destructs the TQtCTDEStyle object.
*/
@@ -148,35 +148,35 @@ class TQtCKStyle: public TQCommonStyle
* you to make a late decision about what scrollbar type to use for the
* style after performing some processing in your style's constructor.
- * In most situations however, setting the scrollbar type via the TQtCKStyle
+ * In most situations however, setting the scrollbar type via the TQtCTDEStyle
* constructor should suffice.
* @param sbtype the scroll bar type
@@ -148,35 +148,35 @@ class TQtCKStyle: public TQCommonStyle
/**
- * Returns the KStyle flags used to initialize the style.
+ * Returns the TDEStyle flags used to initialize the style.
*
* This is used solely for the kcmstyle module, and hence is internal.
@@ -148,35 +148,35 @@ class TQtCKStyle: public TQCommonStyle
/**
- * KStyle Primitive Elements:
+ * TDEStyle Primitive Elements:
*
@@ -148,35 +148,35 @@ class TQtCKStyle: public TQCommonStyle
*
- * The KStyle class extends the TQt's Style API by providing certain
- * simplifications for parts of TQStyle. To do this, the KStylePrimitive
+ * The TDEStyle class extends the TQt's Style API by providing certain
+ * simplifications for parts of TQStyle. To do this, the TDEStylePrimitive
* elements were defined, which are very similar to TQt's PrimitiveElement.
*
@@ -148,35 +148,35 @@ class TQtCKStyle: public TQCommonStyle
*
* The first three Handle primitives simplify and extend PE_DockWindowHandle,
- * so do not reimplement PE_DockWindowHandle if you want the KStyle handle
+ * so do not reimplement PE_DockWindowHandle if you want the TDEStyle handle
* simplifications to be operable. Similarly do not reimplement CC_Slider,
@@ -148,35 +148,35 @@ class TQtCKStyle: public TQCommonStyle
* simplifications to be operable. Similarly do not reimplement CC_Slider,
- * SC_SliderGroove and SC_SliderHandle when using the KStyle slider
- * primitives. KStyle automatically double-buffers slider painting
- * when they are drawn via these KStyle primitives to avoid flicker.
+ * SC_SliderGroove and SC_SliderHandle when using the TDEStyle slider
+ * primitives. TDEStyle automatically double-buffers slider painting
+ * when they are drawn via these TDEStyle primitives to avoid flicker.
*
@@ -148,35 +148,35 @@ class TQtCKStyle: public TQCommonStyle
*
- * @li KPE_DockWindowHandle - This primitive is already implemented in KStyle,
+ * @li KPE_DockWindowHandle - This primitive is already implemented in TDEStyle,
* and paints a bevelled rect with the DockWindow caption text. Re-implement
* this primitive to perform other more fancy effects when drawing the dock window
@@ -198,14 +198,14 @@ class TQtCKStyle: public TQCommonStyle
* arbitrary color.
*
- * @li KPE_ListViewExpander - This primitive is already implemented in KStyle. It
+ * @li KPE_ListViewExpander - This primitive is already implemented in TDEStyle. It
* is used to draw the Expand/Collapse element in TQListViews. To indicate the
* expanded state, the style flags are set to Style_Off, while Style_On implies collapsed.
@@ -198,14 +198,14 @@ class TQtCKStyle: public TQCommonStyle
* expanded state, the style flags are set to Style_Off, while Style_On implies collapsed.
*
- * @li KPE_ListViewBranch - This primitive is already implemented in KStyle. It is
+ * @li KPE_ListViewBranch - This primitive is already implemented in TDEStyle. It is
* used to draw the ListView branches where necessary.
*/
@@ -220,13 +220,13 @@ class TQtCKStyle: public TQCommonStyle
* This function is identical to TQt's TQStyle::drawPrimitive(), except that
* it adds one further parameter, 'widget', that can be used to determine
- * the widget state of the KStylePrimitive in question.
+ * the widget state of the TDEStylePrimitive in question.
*
diff --git a/style/qtcurve.cpp b/style/qtcurve.cpp
index 4eebbc9..8c2585c 100644
--- a/style/qtcurve.cpp
+++ b/style/qtcurve.cpp
@@ -4477,7 +4477,7 @@ static TQString elliditide(const TQString &text, const TQFontMetrics &fontMetric
return title;
}
-void QtCurveStyle::drawKStylePrimitive(KStylePrimitive kpe, TQPainter *p, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags,
+void QtCurveStyle::drawTDEStylePrimitive(TDEStylePrimitive kpe, TQPainter *p, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags,
const TQRect &r, const TQColorGroup &cg, SFlags flags,
const TQStyleOption &opt, const TQWidget *widget) const
{
@@ -4630,7 +4630,7 @@ void QtCurveStyle::drawKStylePrimitive(KStylePrimitive kpe, TQPainter *p, const
}
break;
default:
- BASE_STYLE::drawKStylePrimitive(kpe, p, ceData, elementFlags, r, cg, flags, opt, widget);
+ BASE_STYLE::drawTDEStylePrimitive(kpe, p, ceData, elementFlags, r, cg, flags, opt, widget);
}
}
@@ -5337,7 +5337,7 @@ void QtCurveStyle::drawControl(ControlElement control, TQPainter *p, const TQSty
if (!cr.isValid())
return;
- if(opts.boldProgress) // This is the only change fro the KStyle code!
+ if(opts.boldProgress) // This is the only change fro the TDEStyle code!
{
TQFont font = p->font();
font.setBold(true);
@@ -6322,7 +6322,7 @@ void QtCurveStyle::drawComplexControl(ComplexControl control, TQPainter *p, cons
}
case CC_Slider:
//
// Note: Can't use KStyle's drawing routine, as this doesnt work for sliders on gradient
// toolbars. It also draws groove, focus, slider - wherease QtCurve needs groove,
// slider, focus. We also ony double-buffer if not on a toolbar, as we dont know
// the background, etc, if on a toolbar - and that is handled in eventFilter
@@ -6885,7 +6885,7 @@ int QtCurveStyle::pixelMetric(PixelMetric metric, const TQStyleControlElementDat
}
}
-int QtCurveStyle::kPixelMetric(KStylePixelMetric kpm, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQWidget *widget) const
+int QtCurveStyle::kPixelMetric(TDEStylePixelMetric kpm, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQWidget *widget) const
{
switch(kpm)
{
@@ -6322,7 +6322,7 @@ void QtCurveStyle::drawComplexControl(ComplexControl control, TQPainter *p, cons
case CC_Slider:
//
- // Note: Can't use KStyle's drawing routine, as this doesnt work for sliders on gradient
+ // Note: Can't use TDEStyle's drawing routine, as this doesnt work for sliders on gradient
// toolbars. It also draws groove, focus, slider - wherease QtCurve needs groove,
// slider, focus. We also ony double-buffer if not on a toolbar, as we dont know